# Welcome to MedUX's documentation!


MedUX is an Open Source Electronic Record, in an early (currently Pre-Alpha) state.

It is a basic framework for plugins (using the [GDAPS](https://gdaps.readthedocs.io) plugin system), and just provides a web application with menus, views etc.
Functionality is done in plugins.


Documentation is a WIP.